OC.L10N.register(
    "files_external",
    {
    "External storages" : "Εξωτερική αποθήκευση",
    "Personal" : "Προσωπικά",
    "System" : "Σύστημα",
    "Grant access" : "Παροχή πρόσβασης",
    "Error configuring OAuth1" : "Σφάλμα ρύθμισης του OAuth1",
    "Please provide a valid app key and secret." : "Παρακαλούμε δώστε έγκυρο κλειδί εφαρμογής και μυστικό.",
    "Error configuring OAuth2" : "Σφάλμα ρύθμισης του OAuth2",
    "Generate keys" : "Δημιουργία κλειδιών",
    "Error generating key pair" : "Σφάλμα κατά τη δημιουργία ζεύγους κλειδιών",
    "All users. Type to select user or group." : "Όλοι οι χρήστες. Πληκτρολογήστε για να επιλέξετε χρήστη ή ομάδα.",
    "(group)" : "(ομάδα)",
    "Compatibility with Mac NFD encoding (slow)" : "Συμβατότητα με Mac NFD κωδικόποιηση (αργό) ",
    "Enable encryption" : "Ενεργοποίηση κρυπτογράφησης",
    "Enable previews" : "Ενεργοποίηση προεπισκοπήσεων",
    "Enable sharing" : "Ενεργοποίηση διαμοιρασμού",
    "Check for changes" : "Έλεγχος για αλλαγές",
    "Never" : "Ποτέ",
    "Once every direct access" : "Σε κάθε απευθείας πρόσβαση",
    "Read only" : "Μόνο για ανάγνωση",
    "Delete" : "Διαγραφή",
    "Admin defined" : "Ορίσθηκε διαχειριστής ",
    "Delete storage?" : "Διαγραφή αποθηκευτικού χώρου;",
    "Saved" : "Αποθηκεύτηκαν",
    "Saving..." : "Γίνεται αποθήκευση...",
    "Save" : "Αποθήκευση",
    "Empty response from the server" : "Κενή απάντηση από τον διακομιστή",
    "Couldn't access. Please log out and in again to activate this mount point" : "Αδυναμία πρόσβασης. Παρακαλούμε αποσυνδεθείτε και συνδεθείτε ξανά για ενεργοποίηση του σημείου προσάρτησης",
    "Couldn't get the information from the remote server: {code} {type}" : "Δεν μπορέσαμε να πάρουμε πληροφορίες απο τον απομακρυσμένο εξυπηρετητή: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Δεν μπορέσαμε να πάρουμε την λίστα εξωτερικών σημείων προσάρτησης: {type}",
    "There was an error with message: " : "Υπήρξε σφάλμα στο μήνυμα:",
    "External mount error" : "Σφάλμα εξωτερικής προσάρτησης",
    "external-storage" : "εξωτερική-αποθήκευση",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Αδυναμία λήψης της λίστας των σημείων προσάρτησης δικτύων Windows: Κενή απάντηση από τον διακομιστή",
    "Please enter the credentials for the {mount} mount" : "Παρακαλούμε βάλτε τα διαπιστευτήρια  για την  {mount} προσάρτηση",
    "Username" : "Όνομα χρήστη",
    "Password" : "Κωδικός πρόσβασης",
    "Credentials saved" : "Τα διαπιστευτήρια αποθηκεύτηκαν",
    "Credentials saving failed" : "Αποτυχία αποθήκευσης διαπιστευτηρίων",
    "Credentials required" : "Απαιτούνται διαπιστευτήρια ",
    "Storage with ID \"%d\" not found" : "Αποθηκευτικός χώρος με ID \"%d\" δεν βρέθηκε ",
    "Invalid backend or authentication mechanism class" : "Μη έγκυρη κλάση συστήματος ή μηχανισμού πιστοποίησης",
    "Invalid mount point" : "Μη έγκυρο σημείο ανάρτησης",
    "Objectstore forbidden" : "Απαγορευμένο objectstore",
    "Invalid storage backend \"%s\"" : "Μή έγκυρο σύστημα υποστήριξης αποθήκευσης  \"%s\"",
    "Not permitted to use backend \"%s\"" : "Μη επιτρεπόμενο σύστημα υποστήριξης \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Μη επιτρεπόμενος μηχανισμός πιστοποίησης \"%s\"",
    "Unsatisfied backend parameters" : "Ελλιπείς παράμετροι συστήματος",
    "Unsatisfied authentication mechanism parameters" : "Ελλιπείς παράμετροι μηχανισμού πιστοποίησης",
    "Insufficient data: %s" : "Μη επαρκή δεδομένα: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Αποθηκευτικός χώρος με ID \"%d\" δεν είναι επεξεργάσιμος από τον χρήστη ",
    "Access key" : "Κλειδί πρόσβασης",
    "Secret key" : "Μυστικό κλειδί",
    "Builtin" : "Builtin",
    "None" : "Τίποτα",
    "OAuth1" : "OAuth1",
    "App key" : "Κλειδί εφαρμογής",
    "App secret" : "Μυστικό εφαρμογής",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID πελάτη",
    "Client secret" : "Μυστικό πελάτη",
    "OpenStack v2" : "OpenStack v2",
    "Tenant name" : "Όνομα \"ένοικου\"",
    "Identity endpoint URL" : "URL τελικού σημείου ταυτοποίησης",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Τομέας",
    "Rackspace" : "Rackspace",
    "API key" : "Κλειδί API",
    "Global credentials" : "Παγκόσμια διαπιστευτήρια",
    "Log-in credentials, save in database" : "Διαπιστευτήρια εισόδου, αποθηκεύστε στην βάση δεδομέων",
    "Username and password" : "Όνομα χρήστη και κωδικός πρόσβασης",
    "Log-in credentials, save in session" : "Διαπιστευτήρια εισόδου, αποθηκεύστε στην συνεδρία ",
    "User entered, store in database" : "Χρήστης εισήχθη, τοποθετήστε στην βάση δεδομένων",
    "RSA public key" : "Δημόσιο κλειδί RSA",
    "Public key" : "Δημόσιο κλειδί",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Κάδος",
    "Hostname" : "Όνομα Υπολογιστή",
    "Port" : "Θύρα",
    "Region" : "Περιοχή",
    "Enable SSL" : "Ενεργοποίηση SSL",
    "Enable Path Style" : "Ενεργοποίηση μορφής διαδρομής",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Απομακρυσμένος υποφάκελος",
    "Secure https://" : "Ασφαλής σύνδεση https://",
    "FTP" : "FTP",
    "Host" : "Διακομιστής",
    "Secure ftps://" : "Ασφαλής ftps://",
    "Local" : "Τοπικός",
    "Location" : "Τοποθεσία",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP με σύνδεση με κρυφό κλειδί",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Διαμοιράστε",
    "Show hidden files" : "Εμφάνιση κρυφών αρχείων",
    "SMB / CIFS using OC login" : "SMB / CIFS χρησιμοποιώντας λογαριασμό OC",
    "Username as share" : "Όνομα χρήστη ως διαμοιραζόμενος φάκελος",
    "OpenStack Object Storage" : "Αποθήκη αντικειμένων OpenStack",
    "Service name" : "Όνομα υπηρεσίας",
    "Request timeout (seconds)" : "Χρονικό όριο αιτήματος (δευτερόλεπτα)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Η cURL υποστήριξη στην PHP δεν είναι ενεργοποιημένη. Η προσάρτηση του %s δεν είναι δυνατή. Παρακαλούμε ζητήστε από τον διαχειριστή του συστήματός σας να το εγκαταστήσει. ",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Η FTP υποστήριξη στην PHP δεν είναι ενεργοποιημένη ή εγκατεστημένη. Η προσάρτηση του %s δεν είναι δυνατή. Παρακαλούμε ζητήστε τον διαχειριστή του συστήματός σας να το εγκατασταστήσει. ",
    "External storage support" : "Υποστήριξη εξωτερικής αποθήκευσης",
    "Name" : "Όνομα",
    "Storage type" : "Τύπος αποθηκευτικού χώρου",
    "Scope" : "Εύρος",
    "Open documentation" : "Άνοιγμα τεκμηρίωσης",
    "Folder name" : "Όνομα φακέλου",
    "External storage" : "Εξωτερική αποθήκευση",
    "Authentication" : "Πιστοποίηση",
    "Configuration" : "Ρυθμίσεις",
    "Available for" : "Διαθέσιμο για",
    "Add storage" : "Προσθηκη αποθηκευσης",
    "Advanced settings" : "Ρυθμίσεις για προχωρημένους",
    "Allow users to mount external storage" : "Να επιτρέπεται στους χρήστες η σύνδεση εξωτερικού χώρου"
},
"nplurals=2; plural=(n != 1);");
